This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Patch to remove C9X references from GCC


I've installed as obvious the following patch to get rid of C9X references
in GCC, replacing them with references to C99.

Index: cp/ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/ChangeLog,v
retrieving revision 1.2092
diff -u -r1.2092 ChangeLog
--- ChangeLog	2000/11/24 10:30:44	1.2092
+++ ChangeLog	2000/11/25 19:49:52
@@ -1,3 +1,9 @@
+2000-11-25  Joseph S. Myers  <jsm28@cam.ac.uk>
+
+	* method.c (build_mangled_C9x_name): Rename to
+	build_mangled_C99_name.  Change C9X references in comments to
+	refer to C99.
+
 2000-11-24  Nathan Sidwell  <nathan@codesourcery.com>

 	* parse.y (unary_expr): Move VA_ARG from here ...
Index: testsuite/ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/ChangeLog,v
retrieving revision 1.868
diff -u -r1.868 ChangeLog
--- ChangeLog	2000/11/25 17:38:57	1.868
+++ ChangeLog	2000/11/25 19:49:54
@@ -1,3 +1,9 @@
+2000-11-25  Joseph S. Myers  <jsm28@cam.ac.uk>
+
+	* gcc.c-torture/execute/memcheck/driver.c,
+	gcc.c-torture/execute/memcheck/driver.h, gcc.dg/cpp/if-3.c: Change
+	C9X references to refer to C99.
+
 2000-11-25  Jakub Jelinek  <jakub@redhat.com>

 	* gcc.dg/ultrasp3.c: New test.
Index: testsuite/gcc.c-torture/execute/memcheck/driver.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.c-torture/execute/memcheck/driver.c,v
retrieving revision 1.3
diff -u -r1.3 driver.c
--- driver.c	1999/02/03 10:30:24	1.3
+++ driver.c	2000/11/25 19:49:54
@@ -1,6 +1,6 @@
 /* GNU C dependencies:
    Checker support hooks
-   ISO C 9x array element initialization
+   ISO C99 array element initialization
    void-pointer arithmetic */

 #include "driver.h"
Index: testsuite/gcc.c-torture/execute/memcheck/driver.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.c-torture/execute/memcheck/driver.h,v
retrieving revision 1.2
diff -u -r1.2 driver.h
--- driver.h	1998/12/16 22:16:57	1.2
+++ driver.h	2000/11/25 19:49:54
@@ -1,6 +1,6 @@
 /* GNU C dependencies:
    Checker support hooks
-   ISO C 9x array element initialization
+   ISO C99 array element initialization
    void-pointer arithmetic */

 typedef __SIZE_TYPE__ size_t;
Index: testsuite/gcc.dg/cpp/if-3.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/cpp/if-3.c,v
retrieving revision 1.1
diff -u -r1.1 if-3.c
--- if-3.c	2000/06/27 22:26:11	1.1
+++ if-3.c	2000/11/25 19:49:54
@@ -1,5 +1,5 @@
 /* Test that the preprocessor is capable of 64-bit arithmetic.
-   (Must turn off -pedantic, since `LL' constants are only in C9x.)  */
+   (Must turn off -pedantic, since `LL' constants are only in C99.)  */
 /* { dg-do preprocess } */
 /* { dg-options "" } */


Index: cp/method.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/method.c,v
retrieving revision 1.179
diff -u -r1.179 method.c
--- method.c	2000/11/02 19:03:58	1.179
+++ method.c	2000/11/25 19:49:53
@@ -92,7 +92,7 @@
 static void build_overload_scope_ref PARAMS ((tree));
 static void build_mangled_template_parm_index PARAMS ((const char *, tree));
 #if HOST_BITS_PER_WIDE_INT >= 64
-static void build_mangled_C9x_name PARAMS ((int));
+static void build_mangled_C99_name PARAMS ((int));
 #endif
 static int is_back_referenceable_type PARAMS ((tree));
 static int check_btype PARAMS ((tree));
@@ -652,7 +652,7 @@
 }


 /* Mangling for C9X integer types (and Cygnus extensions for 128-bit
    and other types) is based on the letter "I" followed by the hex
    representations of the bitsize for the type in question. For
    encodings that result in larger than two digits, a leading and
@@ -674,7 +674,7 @@

 #if HOST_BITS_PER_WIDE_INT >= 64
 static void
-build_mangled_C9x_name (bits)
+build_mangled_C99_name (bits)
      int bits;
 {
   char mangled[10] = "";
@@ -1454,7 +1454,7 @@
       else
 	{
 	  int bits = TREE_INT_CST_LOW (TYPE_SIZE (parmtype));
-	  build_mangled_C9x_name (bits);
+	  build_mangled_C99_name (bits);
 	}
 #else
       else
@@ -652,7 +652,7 @@


-/* Mangling for C9X integer types (and Cygnus extensions for 128-bit
+/* Mangling for C99 integer types (and Cygnus extensions for 128-bit
    and other types) is based on the letter "I" followed by the hex
    representations of the bitsize for the type in question. For
-- 
Joseph S. Myers
jsm28@cam.ac.uk


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]